@@ -6,6 +6,7 @@ use warnings;
 use Try::Tiny;
 use Capture::Tiny ':all';
 use IO::Socket::INET;
+use File::Temp qw( tempfile );
 
 =head1 NAME
 
@@ -13,9 +14,7 @@ Net::Hacky::Detect::IP - Hackily try different methods of attaining local system
 
 =head1 WARNING
 
-This module currently only supports ipv4 and linux, BSD and MAC. Windows support is partially built in, and will be added 
-shortly, unfortunatly I lack a machine to develop it on at present. This module will also eventually check and return 
-valid IPv6 addresses.
+This module does not yet support returning IPv6 addresses, though will do soon!
 
 =head1 README
 
@@ -26,11 +25,11 @@ and any other relevant data.
 
 =head1 VERSION
 
-Version 0.013
+Version 0.014
 
 =cut
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 my $tools = {
     unix => {
@@ -39,10 +38,27 @@ my $tools = {
     },
     windows => {
         tools => [[qw(netstat -an)],[qw(ipconfig)],[qw(cscript)]],
-        paths => []
+        paths => [""]
     }
 };
 
+my $cscript = <<'EOF';
+
+On Error Resume Next
+strComputer = "."
+Set objWMIService = GetObject("winmgmts:\\" & strComputer & "\root\CIMV2")
+Set colItems = objWMIService.ExecQuery("SELECT * FROM Win32_NetworkAdapterConfiguration")
+
+For Each objItem In colItems
+    For Each objValue In objItem.IPAddress
+        If objValue <> "" Then
+        WScript.Echo objValue
+        End If
+    Next
+Next
+
+EOF
+
 =head1 SYNOPSIS
 
     use Net::Hacky::Detect::IP;
@@ -74,6 +90,7 @@ sub scan {
     # Some short cuts and initial scalars for storing things in
     my $dumps = "";
     my $short = $tools->{$os};
+    my $winScript;
 
     # Go searching for something we can use
     foreach my $tool ( @{ $short->{tools} } ) {
@@ -86,8 +103,13 @@ sub scan {
             my ($merged, @result);
 
             # If this is a call for cscript, we need to act differently..
-            if ($tool eq 'cscript') { 
-                # .... do stuff
+            if ($cmd eq 'cscript') {
+                $winScript = File::Temp::tempdir() . '\\' . 'findip.vbs';
+                open(my $fh,'>',$winScript);
+                print $fh $cscript;
+                close($fh);
+
+                push @args,$winScript;
             }
             
             # If we are on unix we do not need to execute everything we can check the path exists.
